#include "touch_master.h"

void touch_init(void){
#ifdef OVERRIDE_ADC
	CloseADC10(); // ensure ADC is off before configuring it

	// Turn module on | ouput in integer | trigger mode auto | enable autosample
	#define PARAM1  ADC_CLK_AUTO | ADC_AUTO_SAMPLING_ON

	// ADC ref external  | disable offset test | disable scan mode | do 1 sample | use single buf | alternate mode off
	#define PARAM2  0

	// use peripherial bus clock | set sample time | set ADC clock divider
	#define PARAM3 ADC_SAMPLE_TIME_15 | ADC_CONV_CLK_3Tcy

	// set as analog inputs
	#define PARAM4	ENABLE_AN11_ANA

	// do not assign channels to scan
	#define PARAM5	SKIP_SCAN_ALL

	// use ground as neg ref for A | use AN for input A
	SetChanADC10(ADC_CH0_POS_SAMPLEA_AN11); // configure to sample AN
	OpenADC10(PARAM1, PARAM2, PARAM3, PARAM4, PARAM5); // configure ADC using the parameters defined above

	EnableADC10(); // Enable the AD
#endif
	
	// Enable pull-downs on the two pins to be analog read in
	// to ensure they won't be floating when there's no touch
	YM_PD();
	XM_PD();

	TOUCH_STATE = STATE_DRIVE_READ_X;
}

void touch_getPoint(void)
{
	static UINT16 X = 0;

	touch_point.DONE = 0;

	if (TOUCH_STATE == STATE_DRIVE_READ_X) {
		YP_INPUT();
		YM_INPUT();
		XP_LOW();
		XP_OUTPUT();
		XM_HIGH();
		XM_OUTPUT();
		SetChanADC10(ADC_CH0_POS_SAMPLEA_AN0); // configure to sample AN
		TOUCH_STATE = STATE_ACQ_X;
	} else if (TOUCH_STATE == STATE_ACQ_X) {
		X = ReadADC10(0);
		TOUCH_STATE = STATE_DRIVE_READ_Y;
	} else if (TOUCH_STATE == STATE_DRIVE_READ_Y) {
		XP_INPUT();
		XM_INPUT();
		YP_LOW();
		YP_OUTPUT();
		YM_HIGH();
		YM_OUTPUT();
		SetChanADC10(ADC_CH0_POS_SAMPLEA_AN11); // configure to sample AN
		TOUCH_STATE = STATE_ACQ_Y;
	} else if (TOUCH_STATE == STATE_ACQ_Y) {
		touch_point.Y = ReadADC10(0);
		touch_point.X = X;
		TOUCH_STATE = STATE_DRIVE_READ_X;

		if (touch_point.X < (1023 - TOUCH_THRESHOLD)
				&& touch_point.X > TOUCH_THRESHOLD
				&& touch_point.Y > TOUCH_THRESHOLD
				&& touch_point.Y < (1023 - TOUCH_THRESHOLD)){
			touch_point.Z = 1;
		}
		else{
			touch_point.Z = 0;
		}
		
		touch_point.DONE = 1;
		// data in x,y,z now valid to be read
	}

}

void touch_reset(void){
	touch_point.X = 0;
	touch_point.Y = 0;
	touch_point.Z = 0;
	touch_point.DONE = 0;
	TOUCH_STATE = STATE_DRIVE_READ_X;
}